@@ -1,3 +1,7 @@
+"""
+SAQ
+"""
+
 from saq.job import CronJob, Job, Status
 from saq.queue import Queue
 from saq.worker import Worker
@@ -10,4 +14,4 @@ __all__ = [
     "Worker",
 ]
 
-__version__ = "0.10.0"
+__version__ = "0.22.0"
