@@ -1,6 +1,7 @@
 import argparse
 import logging
 import multiprocessing
+import os
 import sys
 
 from saq.worker import check_health, start
@@ -13,9 +14,7 @@ def main() -> None:
         type=str,
         help="Namespaced variable containing worker settings eg: eg module_a.settings",
     )
-    parser.add_argument(
-        "--workers", type=int, help="Number of worker processes", default=1
-    )
+    parser.add_argument("--workers", type=int, help="Number of worker processes", default=1)
     parser.add_argument(
         "--verbose",
         "-v",
@@ -37,7 +36,7 @@ def main() -> None:
     )
     parser.add_argument(
         "--port",
-        type=str,
+        type=int,
         help="Web app port, defaults to 8080",
     )
     parser.add_argument(
@@ -54,11 +53,14 @@ def main() -> None:
 
     args = parser.parse_args()
 
+    # Includes the current path as a module path to allow importlib finding in-development modules
+    sys.path.append(os.getcwd())
+
     if not args.quiet:
         level = args.verbose
 
         if level == 0:
-            level = logging.ERROR
+            level = logging.WARNING
         elif level == 1:
             level = logging.INFO
         else:
@@ -78,12 +80,15 @@ def main() -> None:
                 p = multiprocessing.Process(target=start, args=(settings,))
                 p.start()
 
-        start(
-            settings,
-            web=args.web,
-            extra_web_settings=args.extra_web_settings,
-            port=args.port,
-        )
+        try:
+            start(
+                settings,
+                web=args.web,
+                extra_web_settings=args.extra_web_settings,
+                port=args.port,
+            )
+        except KeyboardInterrupt:
+            pass
 
 
 if __name__ == "__main__":
